componenttools.shorten_component_by_duration
============================================

.. autofunction:: abjad.tools.componenttools.shorten_component_by_duration.shorten_component_by_duration
   :noindex:
